==> tencentcloud-sdk-java-3.1.79-sources.jar: com/tencentcloudapi/tcb/v20180608/models/DescribePostpayPackageFreeQuotasRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tcb.v20180608.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribePostpayPackageFreeQuotasRequest extends AbstractModel{

    /**
    * 环境ID
    */
    @SerializedName("EnvId")
    @Expose
    private String EnvId;

    /**
    * 免费额度类型标识
    */
    @SerializedName("FreeQuotaType")
    @Expose
    private String FreeQuotaType;

    /**
     * Get 环境ID 
     * @return EnvId 环境ID
     */
    public String getEnvId() {
        return this.EnvId;
    }

    /**
     * Set 环境ID
     * @param EnvId 环境ID
     */
    public void setEnvId(String EnvId) {
        this.EnvId = EnvId;
    }

    /**
     * Get 免费额度类型标识 
     * @return FreeQuotaType 免费额度类型标识
     */
    public String getFreeQuotaType() {
        return this.FreeQuotaType;
    }

    /**
     * Set 免费额度类型标识
     * @param FreeQuotaType 免费额度类型标识
     */
    public void setFreeQuotaType(String FreeQuotaType) {
        this.FreeQuotaType = FreeQuotaType;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "EnvId", this.EnvId);
        this.setParamSimple(map, prefix + "FreeQuotaType", this.FreeQuotaType);

    }
}

==> tencentcloud-sdk-java-3.1.268-sources.jar: com/tencentcloudapi/tcb/v20180608/models/DescribePostpayPackageFreeQuotasRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tcb.v20180608.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribePostpayPackageFreeQuotasRequest extends AbstractModel{

    /**
    * 环境ID
    */
    @SerializedName("EnvId")
    @Expose
    private String EnvId;

    /**
    * 免费额度类型标识
    */
    @SerializedName("FreeQuotaType")
    @Expose
    private String FreeQuotaType;

    /**
     * Get 环境ID 
     * @return EnvId 环境ID
     */
    public String getEnvId() {
        return this.EnvId;
    }

    /**
     * Set 环境ID
     * @param EnvId 环境ID
     */
    public void setEnvId(String EnvId) {
        this.EnvId = EnvId;
    }

    /**
     * Get 免费额度类型标识 
     * @return FreeQuotaType 免费额度类型标识
     */
    public String getFreeQuotaType() {
        return this.FreeQuotaType;
    }

    /**
     * Set 免费额度类型标识
     * @param FreeQuotaType 免费额度类型标识
     */
    public void setFreeQuotaType(String FreeQuotaType) {
        this.FreeQuotaType = FreeQuotaType;
    }

    public DescribePostpayPackageFreeQuotasRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribePostpayPackageFreeQuotasRequest(DescribePostpayPackageFreeQuotasRequest source) {
        if (source.EnvId != null) {
            this.EnvId = new String(source.EnvId);
        }
        if (source.FreeQuotaType != null) {
            this.FreeQuotaType = new String(source.FreeQuotaType);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "EnvId", this.EnvId);
        this.setParamSimple(map, prefix + "FreeQuotaType", this.FreeQuotaType);

    }
}
